@@ -1,3 +1,6 @@
+from functools import cache
+
+
 class EventType:
     BAN = "BAN"
     BROADCAST = "BROADCAST"
@@ -13,3 +16,8 @@ class EventType:
     SUBONLY = "SUBONLY"
     UNBAN = "UNBAN"
     UNMUTE = "UNMUTE"
+
+    @classmethod
+    @cache
+    def types(cls) -> tuple[str]:
+        return tuple(v for k, v in cls.__dict__.items() if k.isupper())
